import React from 'react';
import {FormItem, FormControlProps} from './Item';
import {Schema} from '../../types';
import {autobind} from '../../utils/helper';

export interface CompositionProps extends FormControlProps {
  condition: string;
  mainType: Schema;
  subType: Schema;
  [propName:string]: any;
}

export default class CompositionControl extends React.Component<CompositionProps> {

  @autobind
  handleChange(value:any) {
    const {onChange} = this.props;
    onChange && onChange(value);
  }

  renderMain() {
    const {name, mainType, render} = this.props;
    let mainSchema = {
      type: 'control',
      control: {
        ...mainType,
        name,
        label: false
      }
    };
    return render('', mainSchema, {onChange: this.handleChange}) as JSX.Element;
  }

  renderSub() {
    const {condition, subType, render} = this.props;
    let subSchema = {
      type: 'control',
      control: {
        ...subType,
        // name: 'danger',
        visibleOn: condition,
        label: false
      }
    };
    return render('', subSchema) as JSX.Element;
  }

  render() {
    return (
      <>
        {this.renderMain()}
        {this.renderSub()}
      </>
    )
  }
}

@FormItem({
  type: 'composition'
})
export class CompositionControlRenderer extends CompositionControl {}
